==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/sqlserver/v20180328/models/ModifyDBInstanceRenewFlagRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.sqlserver.v20180328.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ModifyDBInstanceRenewFlagRequest  extends AbstractModel{

    /**
    * 实例续费状态标记信息
    */
    @SerializedName("RenewFlags")
    @Expose
    private InstanceRenewInfo [] RenewFlags;

    /**
     * 获取实例续费状态标记信息
     * @return RenewFlags 实例续费状态标记信息
     */
    public InstanceRenewInfo [] getRenewFlags() {
        return this.RenewFlags;
    }

    /**
     * 设置实例续费状态标记信息
     * @param RenewFlags 实例续费状态标记信息
     */
    public void setRenewFlags(InstanceRenewInfo [] RenewFlags) {
        this.RenewFlags = RenewFlags;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "RenewFlags.", this.RenewFlags);

    }
}

==> tencentcloud-sdk-java-3.1.97-sources.jar: com/tencentcloudapi/sqlserver/v20180328/models/ModifyDBInstanceRenewFlagRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.sqlserver.v20180328.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ModifyDBInstanceRenewFlagRequest extends AbstractModel{

    /**
    * 实例续费状态标记信息
    */
    @SerializedName("RenewFlags")
    @Expose
    private InstanceRenewInfo [] RenewFlags;

    /**
     * Get 实例续费状态标记信息 
     * @return RenewFlags 实例续费状态标记信息
     */
    public InstanceRenewInfo [] getRenewFlags() {
        return this.RenewFlags;
    }

    /**
     * Set 实例续费状态标记信息
     * @param RenewFlags 实例续费状态标记信息
     */
    public void setRenewFlags(InstanceRenewInfo [] RenewFlags) {
        this.RenewFlags = RenewFlags;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "RenewFlags.", this.RenewFlags);

    }
}
